local PocketAdeptus = PocketAdeptus
local LAM2 = LibAddonMenu2

function PocketAdeptus.createSettingsWindow()
     if PocketAdeptus.useGlobalVars then
          svsettings = PocketAdeptusVars["Default"][GetDisplayName()]['$AccountWide']
     else
          svsettings = PocketAdeptusCharacterVars["Default"][GetDisplayName()][GetCurrentCharacterId()]
     end

     local panelData = {
          type = "panel",
          name = "Pocket Adeptus",
          displayName = "|cAD601CPocket Adeptus Settings|r",
          author = "|c513DEB" .. PocketAdeptus.author .. "|r",
          version = "|c513DEB" .. PocketAdeptus.version .. "|r",
          slashCommand = "/pocket",
          registerForRefresh = true,
          registerForDefaults = true,
     }
     LAM2:RegisterAddonPanel(PocketAdeptus.version .. "Settings", panelData)

     local Settings = {
          {
               type = "header",
               name = "|cAD601CPocket Adeptus Information|r",
               width = "full"
          },
          {
               type = "description",
               text = "Pocket Adeptus was created to easily save and share raid CP settings",
               width = "full"
          },
          {
               type = "checkbox",
               name = "Auto-confirm CP changes",
               getFunc = function() return svsettings["autoConfirm"] end,
               setFunc = function(value) svsettings["autoConfirm"] = value end,
               disabled = false,
               default = false,
               requiresReload = true
          },
          {
               type = "checkbox",
               name = "Auto-set CP when entering trial",
               tooltip = "If enabled, the addon will set your CP upon entering the trial. If enabled, this setting will only work in Veteran instances. If you want to set your CP in a normal instance, use the /cpset command",
               getFunc = function() return svsettings["SetOnZoneChange"] end,
               setFunc = function(value) svsettings["SetOnZoneChange"] = value end,
               default = false,
               requiresReload = true
          },
          {
               type = "checkbox",
               name = "Use Global Configuration",
               tooltip = "If enabled, this character will use the global configuration, otherwise it will use per character settings",
               getFunc = function() return PocketAdeptusCharacterVars["Default"][GetDisplayName()][GetCurrentCharacterId()]["useGlobalVars"] end,
               setFunc = function(value) PocketAdeptusCharacterVars["Default"][GetDisplayName()][GetCurrentCharacterId()]["useGlobalVars"] = value end,
               default = true,
               requiresReload = true
          },
          {
               type = "button",
               name = "Update CP",
               warning = "Updates to the newest version of Pocket Adeptus CP. THIS WILL OVERRIDE CUSTOM TRIAL PRESETS",
               func = function() PocketAdeptus.UpdateCP() end
          },
          {
               type = "submenu",
               name = "|cAD601CAetherian Archive|r",
               tooltip = "CP Settings for Veteran Aetherian Archive",
               controls = {
                    {
                         type = "header",
                         name = "|c513DEBThe Steed|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Ironclad",
                         tooltip = "Reduces your damage taken against direct damage attacks",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["aa"]["ironclad"] end,
                         getFunc = function() return svsettings["aa"]["ironclad"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["aa"]["ironclad"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,

                    },
                    {
                         type = "editbox",
                         name = "Spell Shield",
                         tooltip = "Increases your Spell Resistance",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["aa"]["spellShield"] end,
                         getFunc = function() return svsettings["aa"]["spellShield"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["aa"]["spellShield"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Medium Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Medium Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["aa"]["mediumArmorFocus"] end,
                         getFunc = function() return svsettings["aa"]["mediumArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["aa"]["mediumArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Resistant",
                         tooltip = "Increases your Critical Resistance",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["aa"]["resistant"] end,
                         getFunc = function() return svsettings["aa"]["resistant"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["aa"]["resistant"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "header",
                         name = "|c513DEBThe Lady|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Hardy",
                         tooltip = "Reduces your damage taken from Physical, Poison, and Disease Damage",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["aa"]["hardy"] end,
                         getFunc = function() return svsettings["aa"]["hardy"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["aa"]["hardy"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Thick Skinned",
                         tooltip = "Reduces your damage taken from damage over time effects",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["aa"]["thickSkinned"] end,
                         getFunc = function() return svsettings["aa"]["thickSkinned"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["aa"]["thickSkinned"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Elemental Defender",
                         tooltip = "Reduces your damage taken from Flame, Frost, Shock, and Magic Damage",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["aa"]["eleDefender"] end,
                         getFunc = function() return svsettings["aa"]["eleDefender"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["aa"]["eleDefender"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Light Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Light Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["aa"]["lightArmorFocus"] end,
                         getFunc = function() return svsettings["aa"]["lightArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["aa"]["lightArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "header",
                         name = "|c513DEBThe Lord|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Bastion",
                         tooltip = "Increases the effectiveness of your damage shields",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["aa"]["bastion"] end,
                         getFunc = function() return svsettings["aa"]["bastion"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["aa"]["bastion"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Quick Recovery",
                         tooltip = "Increases your healing received",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["aa"]["quickRecovery"] end,
                         getFunc = function() return svsettings["aa"]["quickRecovery"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["aa"]["quickRecovery"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Expert Defender",
                         tooltip = "Reduces your damage taken from player Light and Heavy Attacks",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["aa"]["expertDefender"] end,
                         getFunc = function() return svsettings["aa"]["expertDefender"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["aa"]["expertDefender"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Heavy Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Heavy Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["aa"]["heavyArmorFocus"] end,
                         getFunc = function() return svsettings["aa"]["heavyArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["aa"]["heavyArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
               },
          },
          {
               type = "submenu",
               name = "|cAD601CAsylum Sanctorium|r",
               tooltip = "CP Settings for Veteran Asylum Sanctorium",
               controls = {
                    {
                         type = "header",
                         name = "|c513DEBThe Steed|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Ironclad",
                         tooltip = "Reduces your damage taken against direct damage attacks",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["as"]["ironclad"] end,
                         getFunc = function() return svsettings["as"]["ironclad"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["as"]["ironclad"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Spell Shield",
                         tooltip = "Increases your Spell Resistance",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["as"]["spellShield"] end,
                         getFunc = function() return svsettings["as"]["spellShield"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["as"]["spellShield"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Medium Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Medium Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["as"]["mediumArmorFocus"] end,
                         getFunc = function() return svsettings["as"]["mediumArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["as"]["mediumArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Resistant",
                         tooltip = "Increases your Critical Resistance",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["as"]["resistant"] end,
                         getFunc = function() return svsettings["as"]["resistant"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["as"]["resistant"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "header",
                         name = "|c513DEBThe Lady|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Hardy",
                         tooltip = "Reduces your damage taken from Physical, Poison, and Disease Damage",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["as"]["hardy"] end,
                         getFunc = function() return svsettings["as"]["hardy"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["as"]["hardy"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Thick Skinned",
                         tooltip = "Reduces your damage taken from damage over time effects",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["as"]["thickSkinned"] end,
                         getFunc = function() return svsettings["as"]["thickSkinned"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["as"]["thickSkinned"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Elemental Defender",
                         tooltip = "Reduces your damage taken from Flame, Frost, Shock, and Magic Damage",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["as"]["eleDefender"] end,
                         getFunc = function() return svsettings["as"]["eleDefender"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["as"]["eleDefender"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Light Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Light Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["as"]["lightArmorFocus"] end,
                         getFunc = function() return svsettings["as"]["lightArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["as"]["lightArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "header",
                         name = "|c513DEBThe Lord|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Bastion",
                         tooltip = "Increases the effectiveness of your damage shields",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["as"]["bastion"] end,
                         getFunc = function() return svsettings["as"]["bastion"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["as"]["bastion"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Quick Recovery",
                         tooltip = "Increases your healing received",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["as"]["quickRecovery"] end,
                         getFunc = function() return svsettings["as"]["quickRecovery"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["as"]["quickRecovery"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Expert Defender",
                         tooltip = "Reduces your damage taken from player Light and Heavy Attacks",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["as"]["expertDefender"] end,
                         getFunc = function() return svsettings["as"]["expertDefender"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["as"]["expertDefender"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Heavy Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Heavy Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["as"]["heavyArmorFocus"] end,
                         getFunc = function() return svsettings["as"]["heavyArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["as"]["heavyArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
               },
          },
          {
               type = "submenu",
               name = "|cAD601CCloudrest|r",
               tooltip = "CP Settings for Veteran Cloudrest",
               controls = {
                    {
                         type = "header",
                         name = "|c513DEBThe Steed|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Ironclad",
                         tooltip = "Reduces your damage taken against direct damage attacks",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["cr"]["ironclad"] end,
                         getFunc = function() return svsettings["cr"]["ironclad"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["cr"]["ironclad"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Spell Shield",
                         tooltip = "Increases your Spell Resistance",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["cr"]["spellShield"] end,
                         getFunc = function() return svsettings["cr"]["spellShield"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["cr"]["spellShield"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Medium Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Medium Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["cr"]["mediumArmorFocus"] end,
                         getFunc = function() return svsettings["cr"]["mediumArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["cr"]["mediumArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Resistant",
                         tooltip = "Increases your Critical Resistance",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["cr"]["resistant"] end,
                         getFunc = function() return svsettings["cr"]["resistant"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["cr"]["resistant"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "header",
                         name = "|c513DEBThe Lady|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Hardy",
                         tooltip = "Reduces your damage taken from Physical, Poison, and Disease Damage",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["cr"]["hardy"] end,
                         getFunc = function() return svsettings["cr"]["hardy"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["cr"]["hardy"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Thick Skinned",
                         tooltip = "Reduces your damage taken from damage over time effects",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["cr"]["thickSkinned"] end,
                         getFunc = function() return svsettings["cr"]["thickSkinned"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["cr"]["thickSkinned"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Elemental Defender",
                         tooltip = "Reduces your damage taken from Flame, Frost, Shock, and Magic Damage",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["cr"]["eleDefender"] end,
                         getFunc = function() return svsettings["cr"]["eleDefender"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["cr"]["eleDefender"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Light Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Light Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["cr"]["lightArmorFocus"] end,
                         getFunc = function() return svsettings["cr"]["lightArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["cr"]["lightArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "header",
                         name = "|c513DEBThe Lord|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Bastion",
                         tooltip = "Increases the effectiveness of your damage shields",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["cr"]["bastion"] end,
                         getFunc = function() return svsettings["cr"]["bastion"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["cr"]["bastion"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Quick Recovery",
                         tooltip = "Increases your healing received",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["cr"]["quickRecovery"] end,
                         getFunc = function() return svsettings["cr"]["quickRecovery"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["cr"]["quickRecovery"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Expert Defender",
                         tooltip = "Reduces your damage taken from player Light and Heavy Attacks",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["cr"]["expertDefender"] end,
                         getFunc = function() return svsettings["cr"]["expertDefender"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["cr"]["expertDefender"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Heavy Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Heavy Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["cr"]["heavyArmorFocus"] end,
                         getFunc = function() return svsettings["cr"]["heavyArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["cr"]["heavyArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
               },
          },
          {
               type = "submenu",
               name = "|cAD601CHalls of Fabrication|r",
               tooltip = "CP Settings for Veteran Halls of Fabrication",
               controls = {
                    {
                         type = "header",
                         name = "|c513DEBThe Steed|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Ironclad",
                         tooltip = "Reduces your damage taken against direct damage attacks",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["hof"]["ironclad"] end,
                         getFunc = function() return svsettings["hof"]["ironclad"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["hof"]["ironclad"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Spell Shield",
                         tooltip = "Increases your Spell Resistance",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["hof"]["spellShield"] end,
                         getFunc = function() return svsettings["hof"]["spellShield"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["hof"]["spellShield"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Medium Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Medium Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["hof"]["mediumArmorFocus"] end,
                         getFunc = function() return svsettings["hof"]["mediumArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["hof"]["mediumArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Resistant",
                         tooltip = "Increases your Critical Resistance",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["hof"]["resistant"] end,
                         getFunc = function() return svsettings["hof"]["resistant"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["hof"]["resistant"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "header",
                         name = "|c513DEBThe Lady|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Hardy",
                         tooltip = "Reduces your damage taken from Physical, Poison, and Disease Damage",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["hof"]["hardy"] end,
                         getFunc = function() return svsettings["hof"]["hardy"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["hof"]["hardy"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Thick Skinned",
                         tooltip = "Reduces your damage taken from damage over time effects",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["hof"]["thickSkinned"] end,
                         getFunc = function() return svsettings["hof"]["thickSkinned"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["hof"]["thickSkinned"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Elemental Defender",
                         tooltip = "Reduces your damage taken from Flame, Frost, Shock, and Magic Damage",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["hof"]["eleDefender"] end,
                         getFunc = function() return svsettings["hof"]["eleDefender"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["hof"]["eleDefender"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Light Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Light Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["hof"]["lightArmorFocus"] end,
                         getFunc = function() return svsettings["hof"]["lightArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["hof"]["lightArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "header",
                         name = "|c513DEBThe Lord|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Bastion",
                         tooltip = "Increases the effectiveness of your damage shields",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["hof"]["bastion"] end,
                         getFunc = function() return svsettings["hof"]["bastion"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["hof"]["bastion"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Quick Recovery",
                         tooltip = "Increases your healing received",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["hof"]["quickRecovery"] end,
                         getFunc = function() return svsettings["hof"]["quickRecovery"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["hof"]["quickRecovery"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Expert Defender",
                         tooltip = "Reduces your damage taken from player Light and Heavy Attacks",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["hof"]["expertDefender"] end,
                         getFunc = function() return svsettings["hof"]["expertDefender"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["hof"]["expertDefender"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Heavy Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Heavy Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["hof"]["heavyArmorFocus"] end,
                         getFunc = function() return svsettings["hof"]["heavyArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["hof"]["heavyArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
               },
          },
          {
               type = "submenu",
               name = "|cAD601CHel Ra Citadel|r",
               tooltip = "CP Settings for Veteran Hel Ra Citadel",
               controls = {
                    {
                         type = "header",
                         name = "|c513DEBThe Steed|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Ironclad",
                         tooltip = "Reduces your damage taken against direct damage attacks",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["hrc"]["ironclad"] end,
                         getFunc = function() return svsettings["hrc"]["ironclad"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["hrc"]["ironclad"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Spell Shield",
                         tooltip = "Increases your Spell Resistance",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["hrc"]["spellShield"] end,
                         getFunc = function() return svsettings["hrc"]["spellShield"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["hrc"]["spellShield"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Medium Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Medium Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["hrc"]["mediumArmorFocus"] end,
                         getFunc = function() return svsettings["hrc"]["mediumArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["hrc"]["mediumArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Resistant",
                         tooltip = "Increases your Critical Resistance",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["hrc"]["resistant"] end,
                         getFunc = function() return svsettings["hrc"]["resistant"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["hrc"]["resistant"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "header",
                         name = "|c513DEBThe Lady|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Hardy",
                         tooltip = "Reduces your damage taken from Physical, Poison, and Disease Damage",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["hrc"]["hardy"] end,
                         getFunc = function() return svsettings["hrc"]["hardy"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["hrc"]["hardy"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Thick Skinned",
                         tooltip = "Reduces your damage taken from damage over time effects",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["hrc"]["thickSkinned"] end,
                         getFunc = function() return svsettings["hrc"]["thickSkinned"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["hrc"]["thickSkinned"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Elemental Defender",
                         tooltip = "Reduces your damage taken from Flame, Frost, Shock, and Magic Damage",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["hrc"]["eleDefender"] end,
                         getFunc = function() return svsettings["hrc"]["eleDefender"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["hrc"]["eleDefender"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Light Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Light Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["hrc"]["lightArmorFocus"] end,
                         getFunc = function() return svsettings["hrc"]["lightArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["hrc"]["lightArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "header",
                         name = "|c513DEBThe Lord|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Bastion",
                         tooltip = "Increases the effectiveness of your damage shields",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["hrc"]["bastion"] end,
                         getFunc = function() return svsettings["hrc"]["bastion"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["hrc"]["bastion"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Quick Recovery",
                         tooltip = "Increases your healing received",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["hrc"]["quickRecovery"] end,
                         getFunc = function() return svsettings["hrc"]["quickRecovery"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["hrc"]["quickRecovery"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Expert Defender",
                         tooltip = "Reduces your damage taken from player Light and Heavy Attacks",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["hrc"]["expertDefender"] end,
                         getFunc = function() return svsettings["hrc"]["expertDefender"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["hrc"]["expertDefender"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Heavy Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Heavy Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["hrc"]["heavyArmorFocus"] end,
                         getFunc = function() return svsettings["hrc"]["heavyArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["hrc"]["heavyArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
               },
          },
          {
               type = "submenu",
               name = "|cAD601CMaw of Lorkhaj|r",
               tooltip = "CP Settings for Veteran Maw of Lorkhaj",
               controls = {
                    {
                         type = "header",
                         name = "|c513DEBThe Steed|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Ironclad",
                         tooltip = "Reduces your damage taken against direct damage attacks",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["mol"]["ironclad"] end,
                         getFunc = function() return svsettings["mol"]["ironclad"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["mol"]["ironclad"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Spell Shield",
                         tooltip = "Increases your Spell Resistance",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["mol"]["spellShield"] end,
                         getFunc = function() return svsettings["mol"]["spellShield"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["mol"]["spellShield"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Medium Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Medium Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["mol"]["mediumArmorFocus"] end,
                         getFunc = function() return svsettings["mol"]["mediumArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["mol"]["mediumArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Resistant",
                         tooltip = "Increases your Critical Resistance",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["mol"]["resistant"] end,
                         getFunc = function() return svsettings["mol"]["resistant"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["mol"]["resistant"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "header",
                         name = "|c513DEBThe Lady|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Hardy",
                         tooltip = "Reduces your damage taken from Physical, Poison, and Disease Damage",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["mol"]["hardy"] end,
                         getFunc = function() return svsettings["mol"]["hardy"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["mol"]["hardy"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Thick Skinned",
                         tooltip = "Reduces your damage taken from damage over time effects",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["mol"]["thickSkinned"] end,
                         getFunc = function() return svsettings["mol"]["thickSkinned"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["mol"]["thickSkinned"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Elemental Defender",
                         tooltip = "Reduces your damage taken from Flame, Frost, Shock, and Magic Damage",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["mol"]["eleDefender"] end,
                         getFunc = function() return svsettings["mol"]["eleDefender"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["mol"]["eleDefender"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Light Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Light Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["mol"]["lightArmorFocus"] end,
                         getFunc = function() return svsettings["mol"]["lightArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["mol"]["lightArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "header",
                         name = "|c513DEBThe Lord|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Bastion",
                         tooltip = "Increases the effectiveness of your damage shields",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["mol"]["bastion"] end,
                         getFunc = function() return svsettings["mol"]["bastion"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["mol"]["bastion"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Quick Recovery",
                         tooltip = "Increases your healing received",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["mol"]["quickRecovery"] end,
                         getFunc = function() return svsettings["mol"]["quickRecovery"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["mol"]["quickRecovery"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Expert Defender",
                         tooltip = "Reduces your damage taken from player Light and Heavy Attacks",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["mol"]["expertDefender"] end,
                         getFunc = function() return svsettings["mol"]["expertDefender"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["mol"]["expertDefender"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Heavy Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Heavy Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["mol"]["heavyArmorFocus"] end,
                         getFunc = function() return svsettings["mol"]["heavyArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["mol"]["heavyArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
               },
          },
          {
               type = "submenu",
               name = "|cAD601CSanctum Ophidia|r",
               tooltip = "CP Settings for Veteran Sanctum Ophidia",
               controls = {
                    {
                         type = "header",
                         name = "|c513DEBThe Steed|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Ironclad",
                         tooltip = "Reduces your damage taken against direct damage attacks",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["so"]["ironclad"] end,
                         getFunc = function() return svsettings["so"]["ironclad"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["so"]["ironclad"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Spell Shield",
                         tooltip = "Increases your Spell Resistance",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["so"]["spellShield"] end,
                         getFunc = function() return svsettings["so"]["spellShield"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["so"]["spellShield"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Medium Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Medium Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["so"]["mediumArmorFocus"] end,
                         getFunc = function() return svsettings["so"]["mediumArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["so"]["mediumArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Resistant",
                         tooltip = "Increases your Critical Resistance",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["so"]["resistant"] end,
                         getFunc = function() return svsettings["so"]["resistant"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["so"]["resistant"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "header",
                         name = "|c513DEBThe Lady|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Hardy",
                         tooltip = "Reduces your damage taken from Physical, Poison, and Disease Damage",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["so"]["hardy"] end,
                         getFunc = function() return svsettings["so"]["hardy"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["so"]["hardy"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Thick Skinned",
                         tooltip = "Reduces your damage taken from damage over time effects",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["so"]["thickSkinned"] end,
                         getFunc = function() return svsettings["so"]["thickSkinned"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["so"]["thickSkinned"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Elemental Defender",
                         tooltip = "Reduces your damage taken from Flame, Frost, Shock, and Magic Damage",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["so"]["eleDefender"] end,
                         getFunc = function() return svsettings["so"]["eleDefender"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["so"]["eleDefender"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Light Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Light Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["so"]["lightArmorFocus"] end,
                         getFunc = function() return svsettings["so"]["lightArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["so"]["lightArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "header",
                         name = "|c513DEBThe Lord|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Bastion",
                         tooltip = "Increases the effectiveness of your damage shields",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["so"]["bastion"] end,
                         getFunc = function() return svsettings["so"]["bastion"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["so"]["bastion"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Quick Recovery",
                         tooltip = "Increases your healing received",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["so"]["quickRecovery"] end,
                         getFunc = function() return svsettings["so"]["quickRecovery"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["so"]["quickRecovery"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Expert Defender",
                         tooltip = "Reduces your damage taken from player Light and Heavy Attacks",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["so"]["expertDefender"] end,
                         getFunc = function() return svsettings["so"]["expertDefender"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["so"]["expertDefender"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Heavy Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Heavy Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["so"]["heavyArmorFocus"] end,
                         getFunc = function() return svsettings["so"]["heavyArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["so"]["heavyArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
               },
          },
          {
               type = "submenu",
               name = "|cAD601CDragonstar Arena|r",
               tooltip = "CP Settings for Veteran Dragonstar Arena",
               controls = {
                    {
                         type = "header",
                         name = "|c513DEBThe Steed|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Ironclad",
                         tooltip = "Reduces your damage taken against direct damage attacks",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["dsa"]["ironclad"] end,
                         getFunc = function() return svsettings["dsa"]["ironclad"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["dsa"]["ironclad"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Spell Shield",
                         tooltip = "Increases your Spell Resistance",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["dsa"]["spellShield"] end,
                         getFunc = function() return svsettings["dsa"]["spellShield"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["dsa"]["spellShield"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Medium Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Medium Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["dsa"]["mediumArmorFocus"] end,
                         getFunc = function() return svsettings["dsa"]["mediumArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["dsa"]["mediumArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Resistant",
                         tooltip = "Increases your Critical Resistance",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["dsa"]["resistant"] end,
                         getFunc = function() return svsettings["dsa"]["resistant"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["dsa"]["resistant"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "header",
                         name = "|c513DEBThe Lady|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Hardy",
                         tooltip = "Reduces your damage taken from Physical, Poison, and Disease Damage",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["dsa"]["hardy"] end,
                         getFunc = function() return svsettings["dsa"]["hardy"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["dsa"]["hardy"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Thick Skinned",
                         tooltip = "Reduces your damage taken from damage over time effects",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["dsa"]["thickSkinned"] end,
                         getFunc = function() return svsettings["dsa"]["thickSkinned"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["dsa"]["thickSkinned"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Elemental Defender",
                         tooltip = "Reduces your damage taken from Flame, Frost, Shock, and Magic Damage",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["dsa"]["eleDefender"] end,
                         getFunc = function() return svsettings["dsa"]["eleDefender"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["dsa"]["eleDefender"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Light Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Light Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["dsa"]["lightArmorFocus"] end,
                         getFunc = function() return svsettings["dsa"]["lightArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["dsa"]["lightArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "header",
                         name = "|c513DEBThe Lord|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Bastion",
                         tooltip = "Increases the effectiveness of your damage shields",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["dsa"]["bastion"] end,
                         getFunc = function() return svsettings["dsa"]["bastion"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["dsa"]["bastion"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Quick Recovery",
                         tooltip = "Increases your healing received",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["dsa"]["quickRecovery"] end,
                         getFunc = function() return svsettings["dsa"]["quickRecovery"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["dsa"]["quickRecovery"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Expert Defender",
                         tooltip = "Reduces your damage taken from player Light and Heavy Attacks",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["dsa"]["expertDefender"] end,
                         getFunc = function() return svsettings["dsa"]["expertDefender"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["dsa"]["expertDefender"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Heavy Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Heavy Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["dsa"]["heavyArmorFocus"] end,
                         getFunc = function() return svsettings["dsa"]["heavyArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["dsa"]["heavyArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
               },
          },
          {
               type = "submenu",
               name = "|cAD601CMaelstrom Arena|r",
               tooltip = "CP Settings for Veteran Maelstrom Arena",
               controls = {
                    {
                         type = "header",
                         name = "|c513DEBThe Steed|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Ironclad",
                         tooltip = "Reduces your damage taken against direct damage attacks",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["ma"]["ironclad"] end,
                         getFunc = function() return svsettings["ma"]["ironclad"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["ma"]["ironclad"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Spell Shield",
                         tooltip = "Increases your Spell Resistance",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["ma"]["spellShield"] end,
                         getFunc = function() return svsettings["ma"]["spellShield"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["ma"]["spellShield"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Medium Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Medium Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["ma"]["mediumArmorFocus"] end,
                         getFunc = function() return svsettings["ma"]["mediumArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["ma"]["mediumArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Resistant",
                         tooltip = "Increases your Critical Resistance",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["ma"]["resistant"] end,
                         getFunc = function() return svsettings["ma"]["resistant"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["ma"]["resistant"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "header",
                         name = "|c513DEBThe Lady|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Hardy",
                         tooltip = "Reduces your damage taken from Physical, Poison, and Disease Damage",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["ma"]["hardy"] end,
                         getFunc = function() return svsettings["ma"]["hardy"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["ma"]["hardy"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Thick Skinned",
                         tooltip = "Reduces your damage taken from damage over time effects",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["ma"]["thickSkinned"] end,
                         getFunc = function() return svsettings["ma"]["thickSkinned"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["ma"]["thickSkinned"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Elemental Defender",
                         tooltip = "Reduces your damage taken from Flame, Frost, Shock, and Magic Damage",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["ma"]["eleDefender"] end,
                         getFunc = function() return svsettings["ma"]["eleDefender"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["ma"]["eleDefender"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Light Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Light Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["ma"]["lightArmorFocus"] end,
                         getFunc = function() return svsettings["ma"]["lightArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["ma"]["lightArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "header",
                         name = "|c513DEBThe Lord|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Bastion",
                         tooltip = "Increases the effectiveness of your damage shields",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["ma"]["bastion"] end,
                         getFunc = function() return svsettings["ma"]["bastion"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["ma"]["bastion"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Quick Recovery",
                         tooltip = "Increases your healing received",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["ma"]["quickRecovery"] end,
                         getFunc = function() return svsettings["ma"]["quickRecovery"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["ma"]["quickRecovery"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Expert Defender",
                         tooltip = "Reduces your damage taken from player Light and Heavy Attacks",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["ma"]["expertDefender"] end,
                         getFunc = function() return svsettings["ma"]["expertDefender"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["ma"]["expertDefender"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Heavy Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Heavy Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["ma"]["heavyArmorFocus"] end,
                         getFunc = function() return svsettings["ma"]["heavyArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["ma"]["heavyArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
               },
          },
          {
               type = "submenu",
               name = "|cAD601CBlackrose Prison|r",
               tooltip = "CP Settings for Blackrose Prison",
               controls = {
                    {
                         type = "header",
                         name = "|c513DEBThe Steed|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Ironclad",
                         tooltip = "Reduces your damage taken against direct damage attacks",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["brp"]["ironclad"] end,
                         getFunc = function() return svsettings["brp"]["ironclad"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["brp"]["ironclad"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Spell Shield",
                         tooltip = "Increases your Spell Resistance",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["brp"]["spellShield"] end,
                         getFunc = function() return svsettings["brp"]["spellShield"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["brp"]["spellShield"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Medium Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Medium Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["brp"]["mediumArmorFocus"] end,
                         getFunc = function() return svsettings["brp"]["mediumArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["brp"]["mediumArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Resistant",
                         tooltip = "Increases your Critical Resistance",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["brp"]["resistant"] end,
                         getFunc = function() return svsettings["brp"]["resistant"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["brp"]["resistant"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "header",
                         name = "|c513DEBThe Lady|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Hardy",
                         tooltip = "Reduces your damage taken from Physical, Poison, and Disease Damage",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["brp"]["hardy"] end,
                         getFunc = function() return svsettings["brp"]["hardy"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["brp"]["hardy"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Thick Skinned",
                         tooltip = "Reduces your damage taken from damage over time effects",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["brp"]["thickSkinned"] end,
                         getFunc = function() return svsettings["brp"]["thickSkinned"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["brp"]["thickSkinned"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Elemental Defender",
                         tooltip = "Reduces your damage taken from Flame, Frost, Shock, and Magic Damage",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["brp"]["eleDefender"] end,
                         getFunc = function() return svsettings["brp"]["eleDefender"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["brp"]["eleDefender"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Light Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Light Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["brp"]["lightArmorFocus"] end,
                         getFunc = function() return svsettings["brp"]["lightArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["brp"]["lightArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "header",
                         name = "|c513DEBThe Lord|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Bastion",
                         tooltip = "Increases the effectiveness of your damage shields",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["brp"]["bastion"] end,
                         getFunc = function() return svsettings["brp"]["bastion"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["brp"]["bastion"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Quick Recovery",
                         tooltip = "Increases your healing received",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["brp"]["quickRecovery"] end,
                         getFunc = function() return svsettings["brp"]["quickRecovery"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["brp"]["quickRecovery"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Expert Defender",
                         tooltip = "Reduces your damage taken from player Light and Heavy Attacks",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["brp"]["expertDefender"] end,
                         getFunc = function() return svsettings["brp"]["expertDefender"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["brp"]["expertDefender"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Heavy Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Heavy Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["brp"]["heavyArmorFocus"] end,
                         getFunc = function() return svsettings["brp"]["heavyArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["brp"]["heavyArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
               },
          },
          {
               type = "submenu",
               name = "|cAD601CSunspire|r",
               tooltip = "CP Settings for Sunspire",
               controls = {
                    {
                         type = "header",
                         name = "|c513DEBThe Steed|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Ironclad",
                         tooltip = "Reduces your damage taken against direct damage attacks",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["ss"]["ironclad"] end,
                         getFunc = function() return svsettings["ss"]["ironclad"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["ss"]["ironclad"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Spell Shield",
                         tooltip = "Increases your Spell Resistance",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["ss"]["spellShield"] end,
                         getFunc = function() return svsettings["ss"]["spellShield"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["ss"]["spellShield"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Medium Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Medium Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["ss"]["mediumArmorFocus"] end,
                         getFunc = function() return svsettings["ss"]["mediumArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["ss"]["mediumArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Resistant",
                         tooltip = "Increases your Critical Resistance",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["ss"]["resistant"] end,
                         getFunc = function() return svsettings["ss"]["resistant"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["ss"]["resistant"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "header",
                         name = "|c513DEBThe Lady|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Hardy",
                         tooltip = "Reduces your damage taken from Physical, Poison, and Disease Damage",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["ss"]["hardy"] end,
                         getFunc = function() return svsettings["ss"]["hardy"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["ss"]["hardy"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Thick Skinned",
                         tooltip = "Reduces your damage taken from damage over time effects",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["ss"]["thickSkinned"] end,
                         getFunc = function() return svsettings["ss"]["thickSkinned"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["ss"]["thickSkinned"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Elemental Defender",
                         tooltip = "Reduces your damage taken from Flame, Frost, Shock, and Magic Damage",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["ss"]["eleDefender"] end,
                         getFunc = function() return svsettings["ss"]["eleDefender"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["ss"]["eleDefender"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Light Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Light Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["ss"]["lightArmorFocus"] end,
                         getFunc = function() return svsettings["ss"]["lightArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["ss"]["lightArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "header",
                         name = "|c513DEBThe Lord|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Bastion",
                         tooltip = "Increases the effectiveness of your damage shields",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["ss"]["bastion"] end,
                         getFunc = function() return svsettings["ss"]["bastion"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["ss"]["bastion"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Quick Recovery",
                         tooltip = "Increases your healing received",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["ss"]["quickRecovery"] end,
                         getFunc = function() return svsettings["ss"]["quickRecovery"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["ss"]["quickRecovery"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Expert Defender",
                         tooltip = "Reduces your damage taken from player Light and Heavy Attacks",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["ss"]["expertDefender"] end,
                         getFunc = function() return svsettings["ss"]["expertDefender"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["ss"]["expertDefender"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Heavy Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Heavy Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["ss"]["heavyArmorFocus"] end,
                         getFunc = function() return svsettings["ss"]["heavyArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["ss"]["heavyArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
               },
          },
          {
               type = "submenu",
               name = "|cAD601CGeneral PvE|r",
               tooltip = "CP Settings for General PvE",
               controls = {
                    {
                         type = "header",
                         name = "|c513DEBThe Steed|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Ironclad",
                         tooltip = "Reduces your damage taken against direct damage attacks",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["gen"]["ironclad"] end,
                         getFunc = function() return svsettings["gen"]["ironclad"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["gen"]["ironclad"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Spell Shield",
                         tooltip = "Increases your Spell Resistance",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["gen"]["spellShield"] end,
                         getFunc = function() return svsettings["gen"]["spellShield"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["gen"]["spellShield"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Medium Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Medium Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["gen"]["mediumArmorFocus"] end,
                         getFunc = function() return svsettings["gen"]["mediumArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["gen"]["mediumArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Resistant",
                         tooltip = "Increases your Critical Resistance",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["gen"]["resistant"] end,
                         getFunc = function() return svsettings["gen"]["resistant"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["gen"]["resistant"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "header",
                         name = "|c513DEBThe Lady|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Hardy",
                         tooltip = "Reduces your damage taken from Physical, Poison, and Disease Damage",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["gen"]["hardy"] end,
                         getFunc = function() return svsettings["gen"]["hardy"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["gen"]["hardy"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Thick Skinned",
                         tooltip = "Reduces your damage taken from damage over time effects",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["gen"]["thickSkinned"] end,
                         getFunc = function() return svsettings["gen"]["thickSkinned"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["gen"]["thickSkinned"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Elemental Defender",
                         tooltip = "Reduces your damage taken from Flame, Frost, Shock, and Magic Damage",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["gen"]["eleDefender"] end,
                         getFunc = function() return svsettings["gen"]["eleDefender"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["gen"]["eleDefender"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Light Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Light Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["gen"]["lightArmorFocus"] end,
                         getFunc = function() return svsettings["gen"]["lightArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["gen"]["lightArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "header",
                         name = "|c513DEBThe Lord|r",
                         title = nil,
                         width = "full",
                    },
                    {
                         type = "editbox",
                         name = "Bastion",
                         tooltip = "Increases the effectiveness of your damage shields",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["gen"]["bastion"] end,
                         getFunc = function() return svsettings["gen"]["bastion"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["gen"]["bastion"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Quick Recovery",
                         tooltip = "Increases your healing received",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["gen"]["quickRecovery"] end,
                         getFunc = function() return svsettings["gen"]["quickRecovery"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["gen"]["quickRecovery"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Expert Defender",
                         tooltip = "Reduces your damage taken from player Light and Heavy Attacks",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["gen"]["expertDefender"] end,
                         getFunc = function() return svsettings["gen"]["expertDefender"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["gen"]["expertDefender"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
                    {
                         type = "editbox",
                         name = "Heavy Armor Focus",
                         tooltip = "Increases your Physical Resistance while wearing 5 or more pieces of Heavy Armor",
                         isMultiline = false,
                         width = "full",
                         default = function() return PocketAdeptus.defaults["gen"]["heavyArmorFocus"] end,
                         getFunc = function() return svsettings["gen"]["heavyArmorFocus"] end,
                         setFunc = function(value) if (tonumber(value) >= 0 and tonumber(value) <= 100) then svsettings["gen"]["heavyArmorFocus"] = tonumber(value) else d("Invalid Must be between 0 and 100") end end,
                    },
               },
          },
     }
     LAM2:RegisterOptionControls(PocketAdeptus.version .. "Settings", Settings)
end
